<!-- 
Author(s): Shibaji Chakraborty, Xueling Shi

Disclaimer:
SCUBAS is under the MIT license found in the root directory LICENSE.md 
Everyone is permitted to copy and distribute verbatim copies of this license 
document.

This version of the MIT Public License incorporates the terms
and conditions of MIT General Public License.
-->

If SCUBAS contributes to a project that leads to a scientific publication, please acknowledge this fact by citing the papers listed below and intermagnet (if used).  

# How to cite SCUBAS
- Chakraborty S, Boteler DH, Shi X, Murphy BS, Hartinger MD, Wang X, Lucas G and Baker JBH (2022) Modeling geomagnetic induction in submarine cables. *Front. Phys.* 10:1022475. [doi:10.3389/fphy.2022.1022475](https://doi.org/10.3389/fphy.2022.1022475)
- Boteler DH, Pirjola RJ. Magnetic and electric fields produced in the sea during geomagnetic disturbances. *Pure Appl Geophys* (2003) 160:1695–716. [doi:10.1007/s00024-003-2372-6](https://doi.org/10.1007/s00024-003-2372-6)
- Wang X, Boteler D, Pirjola R. Distributed-source transmission line theory for modeling the coast effect on geoelectric fields. *IEEE Trans Power Deliv* (2022).

# Publications using SCUBAS
- Boteler, D. H., Chakraborty, S., Shi, X., Hartinger, M. D., & Wang, X. (2024). An examination of geomagnetic induction in submarine cables. Space Weather, 22, e2023SW003687. [doi:10.1029/2023SW003687](https://doi.org/10.1029/2023SW003687)

- Boteler, D. , Chakraborty, S. , Shi, X. , Hartinger, M. and Wang, X. (2023) Transmission Line Modelling of Geomagnetic Induction in the Ocean/Earth Conductivity Structure. International Journal of Geosciences, 14, 767-791. [doi: 10.4236/ijg.2023.148041](https://www.scirp.org/journal/paperinformation?paperid=127339).


# How to cite INTERMAGNET

If you are using INTERMAGNET dataset to drive the model simulation and results are being used in publications, the please cite INTERMAGNET. A detailed description of the data conditions are listed in this [webpage](https://intermagnet.github.io/data_conditions.html).

## Python Library References 

### Matplotlib
John D. Hunter. Matplotlib: A 2D Graphics Environment, Computing in Science & Engineering, 9, 90-95 (2007), [DOI:10.5281/zenodo.3264781](https://zenodo.org/record/3264781)

### NumPy
Stéfan van der Walt, S. Chris Colbert and Gaël Varoquaux. The NumPy Array: A Structure for Efficient Numerical Computation, Computing in Science & Engineering, 13, 22-30 (2011), [DOI:10.1109/MCSE.2011.37](https://ieeexplore.ieee.org/document/5725236)

### SciPy
Pauli Virtanen, Ralf Gommers, Travis E. Oliphant, Matt Haberland, Tyler Reddy, David Cournapeau, Evgeni Burovski, Pearu Peterson, Warren Weckesser, Jonathan Bright, Stéfan J. van der Walt, Matthew Brett, Joshua Wilson, K. Jarrod Millman, Nikolay Mayorov, Andrew R. J. Nelson, Eric Jones, Robert Kern, Eric Larson, CJ Carey, İlhan Polat, Yu Feng, Eric W. Moore, Jake VanderPlas, Denis Laxalde, Josef Perktold, Robert Cimrman, Ian Henriksen, E.A. Quintero, Charles R Harris, Anne M. Archibald, Antônio H. Ribeiro, Fabian Pedregosa, Paul van Mulbregt, and SciPy 1.0 Contributors. (2020) SciPy 1.0: Fundamental Algorithms for Scientific Computing in Python. Nature Methods, 17(3), 261-272

### Pandas
[Data structures for statistical computing in python](https://conference.scipy.org/proceedings/scipy2010/pdfs/mckinney.pdf), McKinney, Proceedings of the 9th Python in Science Conference, Volume 445, 2010.
